PolylinePoints class

Constructors

PolylinePoints()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodePolyline(List encodedString) List<PointLatLng>
getRouteBetweenCoordinates({required PolylineRequest request, String? mapboxApiKey}) Future<PolylineResult>
Get the list of coordinates between two geographical positions which can be used to draw polyline between this two positions
getRouteWithAlternatives({required PolylineRequest request, String? mapboxApiKey}) Future<List<PolylineResult>>
Get the list of coordinates between two geographical positions with alternative routes which can be used to draw polyline between this two positions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited