PolylineRequest class

Constructors

PolylineRequest({Uri? proxy, Map<String, String>? headers, required PointLatLng origin, required PointLatLng destination, required TravelMode mode, List<PolylineWayPoint> wayPoints = const [], bool avoidHighways = false, bool avoidTolls = false, bool avoidFerries = false, bool optimizeWaypoints = false, bool alternatives = false, int? arrivalTime, int? departureTime, String? transitMode})

Properties

alternatives bool
If set to true, specifies that the Directions service may provide more than one route alternative in the response. Note that providing route alternatives may increase the response time from the server. This is only available for requests without intermediate waypoints. For more information, see the guide to waypoints.
final
arrivalTime int?
Specifies the desired time of arrival for transit directions, in seconds since midnight, January 1, 1970 UTC. You can specify either this or departureTime, but not both. Note that it must be specified as an integer.
final
avoidFerries bool
final
avoidHighways bool
final
avoidTolls bool
final
departureTime int?
Specifies the desired time of departure. You can specify the time as an integer in seconds since midnight,
final
destination PointLatLng
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
mode TravelMode
final
optimizeWaypoints bool
final
origin PointLatLng
final
proxy Uri?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitMode String?
Specifies one or more preferred modes of transit. This parameter may only be specified for transit directions. The parameter supports the following arguments: bus rail subway train tram
final
wayPoints List<PolylineWayPoint>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeNulls(Map<String, dynamic> map) Map<String, dynamic>
toString() String
A string representation of this object.
inherited
toUri({String? apiKey}) Uri
validateKey(String? key) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited