PolylineResult class

description: project: flutter_polyline_points_mapbox @package: @author: femivita created on: 17/08/2024

Constructors

PolylineResult({String? status, List<PointLatLng> points = const [], String? errorMessage = ""})

Properties

errorMessage String?
the error message returned from mapbox, if none, the result will be empty
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
points List<PointLatLng>
list of decoded points
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
the api status retuned from mapbox api
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited