If set to true, specifies that the Directions service may provide more
than one route alternative in the response. Note that providing route
alternatives may increase the response time from the server.
This is only available for requests without intermediate waypoints.
For more information, see the guide to waypoints.
Specifies the desired time of arrival for transit directions, in seconds
since midnight, January 1, 1970 UTC. You can specify either this
or departureTime, but not both. Note that it must be specified as an integer.
Specifies one or more preferred modes of transit. This parameter may only
be specified for transit directions.
The parameter supports the following arguments:
bus
rail
subway
train
tram